/**
 * Sample React Native App
 * https://github.com/facebook/react-native
 *
 * @format
 * @flow
 */

import React, { Component } from 'react';
import { connect } from 'react-redux';
import { compose } from 'redux';
import {
  StyleSheet,
  TouchableOpacity,
  View,
} from 'react-native';

import LinearGradient from 'react-native-linear-gradient';
import FastImage from 'react-native-fast-image';
import { TabBar, TabView } from 'react-native-tab-view';
import { LargeList } from 'react-native-largelist-v3';
import { CommonLottieHeader } from 'react-native-spring-scrollview/Customize/CommonLottieHeader';
import { push } from '../../BasicNavigator/actions';
import NavigationBar, { NavHeight } from '../../components/NavigationBar';
import decorator from '../../utils/decorator';
import Text from '../../components/Text';
import { ENV, resourceURLMapping } from '../../utils/constants';
import ListItem from '../InsuranceList/ListItem';
import { queryInsuranceListByUid } from '../InsuranceList/InsuranceAPI';

type Props = {};
const styles = StyleSheet.create({
  container: {
    flex: 1,
    backgroundColor: '#F5FCFF',
  },
  header: {
    height: 150,
  },
  tab: {
    width: global.SCREEN_WIDTH / 4,
  },
  label: {
    fontWeight: 'bold',
    fontSize: 16,
    //color: '#666',
  },
});

const typeArr : Array<> = [
  { key: 'ALL', title: '全部', type: 1 },
  { key: 'SAVE', title: '保障中', type: 41 },
  { key: 'EXPIRED', title: '已失效', type: 10 },
  { key: 'EXPIRED2', title: '其他', type: 10 },
];

const typeData = {
  index: 0,
  routes: typeArr,
};

@decorator
class PolicyPage extends Component<Props> {
  constructor(props) {
    super(props);
    this.itemHeight = (global.SCREEN_WIDTH - 30) * 137 / 345 + 12;
    this.titleHeight = (this.itemHeight - 12) * 80 / 137;
    this.state = {
      data: [],
      type: typeData,
    };
  }

  _handleIndexChange = (index) => {
    const type = {
      index,
      routes: typeArr,
    };
    this.setState({ type });
  };

  renderIndexPath = ({ section, row }) => {
    const { theme, pushTo } = this.props;
    const item = this.state.data[section].items[row];

    return (
      <ListItem
        section={section}
        row={row}
        item={item}
        titleHeight={this.titleHeight}
        itemHeight={this.itemHeight}
        onPress={() => pushTo('InsuranceDetail', item)}
      />
    );
  };

  queryList = async () => {
    const list = await queryInsuranceListByUid({ params: { uid: 'u0000001' } });
    console.log('list:', list);

    if (list) {
      this.setState({
        data: [
          {
            items: list,
          },
        ],
      });
    }
  };

  onRefresh = async () => {
    await this.queryList();
    this.scrollView.endRefresh();
  };

  endRefresh = () => {

  };

  _renderScene = ({ route, jumpTo }) => (
    <LargeList
      ref={(com) => {
        this.scrollView = com;
      }}
      style={{
        backgroundColor: '#F4F5F5',
      }}
      contentStyle={[
        { height: global.SCREEN_HEIGHT - NavHeight - 50, backgroundColor: '#F4F5F5' },
      ]}
      data={this.state.data}
      onRefresh={this.onRefresh}
      endRefresh={this.endRefresh}
      refreshHeader={CommonLottieHeader}
      heightForIndexPath={() => this.itemHeight}
      heightForSection={() => 0}
      renderIndexPath={this.renderIndexPath}
    />
  );

  _renderTabBar = item => (
    <TabBar
      {...item}
      scrollEnabled
      indicatorStyle={{ width:36, backgroundColor: this.props.theme.ThemeColor }}
      style={{ backgroundColor: '#fff', height: 50 }}
      tabStyle={styles.tab}
      labelStyle={[styles.label]}
      activeColor={this.props.theme.ThemeColor}
      inactiveColor="#666"
    />
  )


  render() {
    const { pushTo } = this.props;
    return (
      <View style={[styles.container, { backgroundColor: '#fff' }]}>
        <LinearGradient
          start={{ x: 0.5, y: 0 }}
          end={{ x: 0.5, y: 1 }}
          locations={[0, 1]}
          colors={['#08BFF9', '#4A98E0']}
          style={[styles.header]}
        >
          <View>
            <NavigationBar
              style={{ backgroundColor: '#00000000' }}
              title="保险"
            />
            <View
              style={{
                height: 25,
                flexDirection: 'row',
                marginTop: 8,
                paddingLeft: 15,
              }}
            >
              <Text style={{
                color: '#fff',
                fontSize: 18,
              }}
              >
                太平保险
              </Text>
              <Text
                style={{
                  color: '#fff',
                  fontSize: 12,
                  marginTop: 6,
                  marginLeft: 2,
                }}
              >
                为您精选
              </Text>
            </View>

          </View>
        </LinearGradient>
        <View
          style={{
            height: 86,
            backgroundColor: '#fff',
            borderRadius: 10,
            position: 'absolute',
            zIndex: 3,
            top: 107,
            left: 15,
            right: 15,
            bottom: global.SCREEN_HEIGHT - 193,
            elevation: 20,
            shadowOffset: { width: 0, height: 0 },
            shadowColor: '#D0DBFF',
            shadowOpacity: 1,
            shadowRadius: 5,
            flexDirection: 'row',
            justifyContent: 'center',
            alignItems: 'center',
          }}
        >
          <View style={{
            flex: 1,
            height: 86,
            flexDirection: 'row',
            justifyContent: 'center',
            alignItems: 'center',
          }}
          >
            <FastImage
              style={{
                width: 36,
                height: 36,

              }}
              source={{
                uri: `${resourceURLMapping[ENV]}insure_wodebaodan.png`,
                priority: FastImage.priority.normal,
              }}
              resizeMode={FastImage.resizeMode.stretch}
            />
            <Text style={{ color: '#333', fontSize: 16, marginLeft: 10 }}>我的保单</Text>

          </View>
          <View style={{ backgroundColor: '#ccc', height: 43, width: 1 }} />
          <View style={{
            flex: 1,
            height: 86,
            flexDirection: 'row',
            justifyContent: 'center',
            alignItems: 'center',
          }}
          >
            <FastImage
              style={{
                width: 36,
                height: 36,
              }}
              source={{
                uri: `${resourceURLMapping[ENV]}insure_wodedingdan.png`,
                priority: FastImage.priority.normal,
              }}
              resizeMode={FastImage.resizeMode.stretch}
            />
            <Text style={{ color: '#333', fontSize: 16, marginLeft: 10 }}>我的订单</Text>
          </View>
        </View>
        <View style={{ height: 43 }} />
        <TabView
          navigationState={this.state.type}
          renderScene={this._renderScene}
          renderTabBar={this._renderTabBar}
          onIndexChange={this._handleIndexChange}
          lazy
          swipeEnabled={false}
          swipeDistanceThreshold={global.SCREEN_WIDTH / 10}
          initialLayout={{ width: global.SCREEN_WIDTH }}
        />
      </View>
    );
  }
}


function actionMapping(dispatch) {
  return {
    pushTo: compose(dispatch, push),
  };
}

function propsMapping({ theme }) {
  return {
    theme,
  };
}

export default connect(propsMapping, actionMapping)(PolicyPage);
